<?php
/**
 * Custom widget to build the home page.
 * - Block three
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class EditorPro_Home_Block_Three_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		parent::__construct(
			'editorpro_home_block_three',
			esc_html__( '&raquo; Block Three', 'editorpro' ),
			array(
				'classname'   => 'editorpro-home-block-three block-widget',
				'description' => esc_html__( 'Home page builder: Block Three', 'editorpro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->defaults = array(
			'title'      => esc_html__( 'Latest News', 'editorpro' ),
			'number'     => '4',
			'taxonomy'   => '',
			'terms'      => '',
			'order'      => 'DESC',
			'orderby'    => 'date',

			// Custom style
			'columns'        => 'two-columns',
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 * @since 1.0.0
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		// Parse instance
		extract( wp_parse_args( $instance, $this->defaults ) );

		// Apply filters to the title
		$title = isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';

		// Before widget WP hook
		echo $args['before_widget'];

			// Show widget title
			if ( $title ) {
				echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
			}

			// Wrapper classes
			$wrap_classes   = array( 'editorpro-block-three', 'posts-grid' );
			$wrap_classes[] = $columns;
			$wrap_classes   = implode( ' ', $wrap_classes ); ?>

			<div class="<?php echo esc_attr( $wrap_classes ); ?>">

				<?php
				// Query args
				$query_args = array(
					'post_type'      => 'post',
					'posts_per_page' => $number,
					'no_found_rows'  => true,
				);

				// Order params - needs FALLBACK don't ever edit!
				if ( ! empty( $orderby ) ) {
					$query_args['order']   = $order;
					$query_args['orderby'] = $orderby;
				} else {
					$query_args['orderby'] = $order; // THIS IS THE FALLBACK
				}

				// Taxonomy args
				if ( ! empty( $taxonomy ) && ! empty( $terms ) ) {

					// Sanitize terms and convert to array
					$terms = str_replace( ', ', ',', $terms );
					$terms = explode( ',', $terms );

					// Add to query arg
					$query_args['tax_query']  = array(
						array(
							'taxonomy' => $taxonomy,
							'field'    => 'slug',
							'terms'    => $terms,
						),
					);

				}

				// Exclude current post
				if ( is_singular() ) {
					$query_args['post__not_in'] = array( get_the_ID() );
				}

				// Query posts
				$editorpro_query = new WP_Query( $query_args );

				if ( $editorpro_query->have_posts() ) :

					while ( $editorpro_query->have_posts() ) : $editorpro_query->the_post(); ?>

						<article id="post-<?php the_ID(); ?>" <?php post_class( 'entry-grid' ); ?>>

							<?php if ( has_post_thumbnail() ) { ?>
								<?php editorpro_post_thumbnail( 'editorpro-post-featured', true ); ?>
							<?php } ?>

							<header class="entry-header">

								<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

								<div class="entry-meta">
									<?php editorpro_post_meta( false ); ?>
								</div>

							</header>

						</article>

					<?php endwhile; ?>

				<?php else : ?>

					<p class="not-found">
						<?php esc_html_e( 'No posts found.', 'editorpro' ); ?>
					</p>

				<?php endif; ?>

			</div>

			<?php wp_reset_postdata(); ?>

		<?php
		// After widget WP hook
		echo $args['after_widget'];

	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 * @since 1.0.0
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance 				= $old_instance;
		$instance['title']      = ! empty( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['taxonomy']   = ! empty( $new_instance['taxonomy'] ) ? strip_tags( $new_instance['taxonomy'] ) : '';
		$instance['terms']      = ! empty( $new_instance['terms'] ) ? strip_tags( $new_instance['terms'] ) : '';
		$instance['number']     = ! empty( $new_instance['number'] ) ? strip_tags( $new_instance['number'] ) : '';
		$instance['order']      = ! empty( $new_instance['order'] ) ? strip_tags( $new_instance['order'] ) : '';
		$instance['orderby']    = ! empty( $new_instance['orderby'] ) ? strip_tags( $new_instance['orderby'] ) : '';

		$instance['columns']        = ! empty( $new_instance['columns'] ) ? strip_tags( $new_instance['columns'] ) : '';

		return $instance;
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 * @since 1.0.0
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		extract( wp_parse_args( ( array ) $instance, $this->defaults ) ); ?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'editorpro' ); ?></label>
			<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<strong><?php esc_html_e( 'Style', 'editorpro' ); ?></strong>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php esc_html_e( 'Columns', 'editorpro' ); ?></label>
			<br />
			<select class='editorpro-select' name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>" style="width:100%;">
				<option value="two-columns" <?php selected( $columns, 'two-columns', true ); ?>><?php esc_html_e( '2 Columns', 'editorpro' ); ?></option>
				<option value="three-columns" <?php selected( $columns, 'three-columns', true ); ?>><?php esc_html_e( '3 Columns', 'editorpro' ); ?></option>
			</select>
		</p>

		<p>
			<strong><?php esc_html_e( 'Post Settings', 'editorpro' ); ?></strong>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number', 'editorpro' ); ?></label>
			<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" min="0" step="1" value="<?php echo esc_attr( $number ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'taxonomy' ) ); ?>"><?php esc_html_e( 'Query By Taxonomy', 'editorpro' ); ?></label>
			<br />
			<select class='editorpro-select' name="<?php echo esc_attr( $this->get_field_name( 'taxonomy' ) ); ?>" style="width:100%;">
				<option value="" <?php if ( ! $taxonomy ) { ?>selected="selected"<?php } ?>><?php esc_html_e( 'No', 'editorpro' ); ?></option>
				<?php
				// Get Taxonomies
				$get_taxonomies = get_taxonomies( array(
					'public' => true,
				), 'objects' ); ?>
				<?php foreach ( $get_taxonomies as $get_taxonomy ) : ?>
					<option value="<?php echo esc_attr( $get_taxonomy->name ); ?>" <?php selected( $taxonomy, $get_taxonomy->name ); ?>><?php echo esc_html( ucfirst( $get_taxonomy->labels->singular_name ) ); ?></option>
				<?php endforeach; ?>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'terms' ) ); ?>"><?php esc_html_e( 'Terms', 'editorpro' ); ?></label>
			<br />
			<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'terms' ) ); ?>" type="text" value="<?php echo esc_attr( $terms ); ?>" />
			<small><?php esc_html_e( 'Enter the term slugs to query by seperated by a "comma"', 'editorpro' ); ?></small>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>"><?php esc_html_e( 'Order', 'editorpro' ); ?></label>
			<br />
			<select class='editorpro-select' name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>" style="width:100%;">
				<option value="DESC" <?php selected( $order, 'DESC', true ); ?>><?php esc_html_e( 'Descending', 'editorpro' ); ?></option>
				<option value="ASC" <?php selected( $order, 'ASC', true ); ?>><?php esc_html_e( 'Ascending', 'editorpro' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>"><?php esc_html_e( 'Order By', 'editorpro' ); ?>:</label>
			<br />
			<select class='editorpro-select' name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>" style="width:100%;">
			<?php
			// Orderby options
			$orderby_array = array (
				'date'          => esc_html__( 'Date', 'editorpro' ),
				'title'         => esc_html__( 'Title', 'editorpro' ),
				'modified'       => esc_html__( 'Modified', 'editorpro' ),
				'author'        => esc_html__( 'Author', 'editorpro' ),
				'rand'          => esc_html__( 'Random', 'editorpro' ),
				'comment_count' => esc_html__( 'Comment Count', 'editorpro' ),
			);
			foreach ( $orderby_array as $key => $value ) { ?>
				<option value="<?php echo esc_attr( $key ); ?>" <?php selected( $orderby, $key ); ?>>
					<?php echo esc_attr( strip_tags( $value ) ); ?>
				</option>
			<?php } ?>
			</select>
		</p>

	<?php

	}

}
register_widget( 'EditorPro_Home_Block_Three_Widget' );
