<?php
/**
 * Custom meta box layout.
 */

/**
 * Get the post layout based on the given post ID.
 */
function editorpro_get_post_layout( $post_id ) {

	// Get the post layout.
	$layout = get_post_meta( $post_id, '_editorpro_post_layout', true );

	// Return the layout if one is found.  Otherwise, return 'default'.
	return ( !empty( $layout ) ? $layout : 'default' );
}

/**
 * Registers new meta box.
 */
function editorpro_post_layouts_box() {

	$screens = [ 'post', 'page' ];
	$screens = apply_filters( 'editorpro_post_layouts_screen', $screens );
	foreach ( $screens as $screen ) {
		add_meta_box(
			'editorpro_post_layouts',              // Unique ID
			esc_html__( 'Layouts', 'editorpro' ),  // Box title
			'editorpro_post_layouts_html',         // Content callback, must be of type callable
			$screen,                               // Post type
			'side'                                 // Context
		);
	}

}
add_action( 'add_meta_boxes', 'editorpro_post_layouts_box' );

/**
 * Displays the content of the meta boxes.
 */
function editorpro_post_layouts_html( $post ) {
	$post_layout = editorpro_get_post_layout( $post->ID );
	wp_nonce_field( 'editorpro_layout_save', 'editorpro_layout_nonce' );
?>

	<p><?php esc_html_e( 'Setup the layout for this page.', 'editorpro' ); ?>
	<p>
		<label>
			<input type="radio" name="editorpro_layout" id="editorpro_layout" value="default" <?php checked( $post_layout, 'default' ); ?> />
			<?php esc_html_e( 'Default', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_layout" id="editorpro_layout" value="right-sidebar" <?php checked( $post_layout, 'right-sidebar' ); ?> />
			<?php esc_html_e( 'Right Sidebar', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_layout" id="editorpro_layout" value="left-sidebar" <?php checked( $post_layout, 'left-sidebar' ); ?> />
			<?php esc_html_e( 'Left Sidebar', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_layout" id="editorpro_layout" value="full-width" <?php checked( $post_layout, 'full-width' ); ?> />
			<?php esc_html_e( 'Full Width', 'editorpro' ); ?>
		</label>
	</p>
	<p>
		<label>
			<input type="radio" name="editorpro_layout" id="editorpro_layout" value="full-width-narrow" <?php checked( $post_layout, 'full-width-narrow' ); ?> />
			<?php esc_html_e( 'Full Width Narrow', 'editorpro' ); ?>
		</label>
	</p>
<?php
}

/**
 * Saves the metadata.
 */
function editorpro_post_layouts_box_save( $post_id, $post ) {

	// Bail if we're doing an auto save
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
		return;

	// if our nonce isn't there, or we can't verify it, bail
	if ( ! isset( $_POST['editorpro_layout_nonce'] ) || ! wp_verify_nonce( $_POST['editorpro_layout_nonce'], 'editorpro_layout_save' ) )
		return;

	// if our current user can't edit this post, bail
	if ( ! current_user_can( 'edit_posts' ) )
		return;

	// Get the meta key.
	$meta_key = '_editorpro_post_layout';

	// Get the previous post layout.
	$meta_value = editorpro_get_post_layout( $post_id );

	// Get the submitted post layout.
	$new_meta_value = $_POST['editorpro_layout'];

	// If there is no new meta value but an old value exists, delete it.
	if ( current_user_can( 'delete_post_meta', $post_id, $meta_key ) && '' == $new_meta_value && $meta_value )
		delete_post_meta( $post_id, $meta_key );

	// If a new meta value was added and there was no previous value, add it.
	elseif ( current_user_can( 'add_post_meta', $post_id, $meta_key ) && $new_meta_value && '' == $meta_value )
		update_post_meta( $post_id, $meta_key, $new_meta_value );

	// If the old layout doesn't match the new layout, update the post layout meta.
	elseif ( current_user_can( 'edit_post_meta', $post_id, $meta_key ) && $meta_value !== $new_meta_value )
		update_post_meta( $post_id, $meta_key, $new_meta_value );

}
add_action( 'save_post', 'editorpro_post_layouts_box_save', 10, 2 );
