<?php
/**
 * Helper functions
 */

if ( ! function_exists( 'editorpro_pingback_header' ) ) :
	/**
	 * Add a pingback url auto-discovery header for singularly identifiable articles.
	 */
	function editorpro_pingback_header() {
		if ( is_singular() && pings_open() ) {
			echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
		}
	}

	add_action( 'wp_head', 'editorpro_pingback_header' );

endif;

if ( ! function_exists( 'editorpro_body_classes' ) ) :
	/**
	 * Adds classes to the body tag
	 */
	function editorpro_body_classes( $classes ) {

		// Vars
		$post_layout  = editorpro_post_layout();
		$post_style   = editorpro_get_post_style( get_the_ID() );
		$container    = get_theme_mod( 'container_style', 'full-width' );

		// RTL
		if ( is_rtl() ) {
			$classes[] = 'rtl';
		}

		// Main class
		$classes[] = 'editorpro-theme';

		// Container style
		$classes[] = $container . '-container';

		// Sidebar enabled
		if ( 'left-sidebar' == $post_layout
			|| 'right-sidebar' == $post_layout
			&& 'full-width' != $container  ) {
			$classes[] = 'has-sidebar';
		}

		// Post layout
		if ( $post_layout ) {
			$classes[] = $post_layout;
		}

		// Post style
		if ( is_single() ) {
			$classes[] = 'style-' . $post_style;
		}

		// Has featured image.
		if ( is_singular() && has_post_thumbnail() ) {
			$classes[] = 'has-featured-image';
		}

		// Return classes
		return $classes;

	}

	add_filter( 'body_class', 'editorpro_body_classes' );

endif;

if ( ! function_exists( 'editorpro_post_layout' ) ) :
	/**
	 * Returns correct post layout.
	 */
	function editorpro_post_layout() {

		// Define variables
		$class  = 'right-sidebar';
		$meta   = editorpro_get_post_layout( get_the_ID() );

		// Check meta first to override and return (prevents filters from overriding meta)
		if ( is_singular() && $meta != 'default' ) {
			$class = $meta;
			return $class;
		}

		// Singular Page
		if ( is_page() ) {

			if ( is_page_template( 'templates/front.php' ) ) {
				$class = 'full-width';
			} else {
				$class = get_theme_mod( 'page_layout', 'right-sidebar' );
			}

		}

		// Attachment
		elseif ( is_attachment() && wp_attachment_is_image() ) {
			$class = 'full-width';
		}

		// Home page template
		elseif ( is_page_template( 'templates/front.php' ) ) {
			$class = 'full-width';
		}

		// Home
		elseif ( is_home() ) {
			$class = get_theme_mod( 'blog_layout', 'right-sidebar' );
		}

		// Archives
		elseif ( is_category()
			|| is_tag()
			|| is_date()
			|| is_author() ) {
			$class = get_theme_mod( 'archive_layout', 'right-sidebar' );
		}

		// Singular Post
		elseif ( is_singular( 'post' ) ) {
			$class = get_theme_mod( 'post_layout', 'right-sidebar' );
		}

		// Library and Elementor template
		elseif ( is_singular( 'elementor_library' ) ) {
			$class = 'full-width';
		}

		// Events post type archive page
		elseif ( is_post_type_archive( 'tribe_events' ) ) {
			$class = 'full-width';
		}

		// 404 page
		elseif ( is_404() ) {
			$class = 'full-width-narrow';
		}

		// All else
		else {
			$class = 'right-sidebar';
		}

		// Class should never be empty
		if ( empty( $class ) ) {
			$class = 'right-sidebar';
		}

		// Apply filters and return
		return apply_filters( 'editorpro_post_layout_class', $class );

	}

endif;

if ( ! function_exists( 'editorpro_get_sidebar' ) ) :
	/**
	 * Returns the correct sidebar region.
	 */
	function editorpro_get_sidebar( $sidebar = 'primary' ) {

		// Return the correct sidebar name & add useful hook
		$sidebar = apply_filters( 'editorpro_get_sidebar', $sidebar );

		// Check meta option after filter so it always overrides
		if ( $meta = get_post_meta( get_the_ID(), 'sidebar', true ) ) {
			$sidebar = $meta;
		}

		// WooCommerce
		if ( editorpro_is_woocommerce_activated() ) {
			if ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) {
				$sidebar = 'woo_sidebar';
			}
		}

		// Never show empty sidebar
		if ( ! is_active_sidebar( $sidebar ) ) {
			$sidebar = 'primary';
		}

		return $sidebar;
	}
endif;

if ( ! function_exists( 'editorpro_archive_header' ) ) :
	/**
	 * Archive header informations.
	 */
	function editorpro_archive_header() {
		?>

		<?php if ( is_archive() && !is_search() ) : ?>
			<div class="archive-header">
				<div class="archive-content">
					<?php the_archive_title( '<h1 class="archive-title">', '</h1>' ); ?>
					<?php the_archive_description( '<div class="archive-desc">', '</div>' ); ?>
				</div>
			</div><!-- .archive-header -->
		<?php endif; ?>

		<?php if ( is_search() ) : ?>
			<div class="archive-header">
				<div class="archive-content">
					<span class="browse"><?php esc_html_e( 'Search Results for', 'editorpro' ); ?></span>
					<h1 class="archive-title"><?php echo get_search_query(); ?></h1>
				</div>
			</div><!-- .archive-header -->
		<?php endif; ?>

	<?php
	}

	add_action( 'editorpro_header', 'editorpro_archive_header', 10 );

endif;

if ( ! function_exists( 'editorpro_post_classes' ) ) :
	/**
	 * Adds custom classes to the array of post classes.
	 */
	function editorpro_post_classes( $classes ) {

		// Replace hentry class with entry.
		$classes[] = 'entry';

		return $classes;
	}

	add_filter( 'post_class', 'editorpro_post_classes' );

endif;

if ( ! function_exists( 'editorpro_remove_hentry' ) ) :
	/**
	 * Remove 'hentry' from post_class()
	 */
	function editorpro_remove_hentry( $class ) {
		$class = array_diff( $class, array( 'hentry' ) );
		return $class;
	}

	add_filter( 'post_class', 'editorpro_remove_hentry' );

endif;

if ( ! function_exists( 'editorpro_excerpt_more' ) ) :
	/**
	 * Change the excerpt more string.
	 */
	function editorpro_excerpt_more( $more ) {
		return '&hellip;';
	}

	add_filter( 'excerpt_more', 'editorpro_excerpt_more' );

endif;

if ( ! function_exists( 'editorpro_custom_excerpt_length' ) ) :
	/**
	 * Filter the excerpt length.
	 */
	function editorpro_custom_excerpt_length( $length ) {

		// Sets default
		$length = 20;

		// Get the user settings
		$setting = get_theme_mod( 'excerpt', 20 );
		if ( 20 != $setting ) {
			$length = $setting;
		}

		return $length;
	}

	add_filter( 'excerpt_length', 'editorpro_custom_excerpt_length', 999 );

endif;

if ( ! function_exists( 'editorpro_extend_archive_title' ) ) :
	/**
	 * Extend archive title
	 */
	function editorpro_extend_archive_title( $title ) {
		if ( is_post_type_archive( 'product' ) ) {
			$default = get_theme_mod( 'shop_title', esc_attr__( 'Products', 'editorpro' ) );
			$title = $default;
		} elseif ( is_post_type_archive( 'tribe_events' ) ) {
			$title = esc_attr__( 'Events', 'editorpro' );
		} elseif ( is_tax() ) {
			$title = single_term_title( '', false );
		} elseif ( is_category() ) {
			$title = single_term_title( '', false );
		}
		return $title;
	}

	add_filter( 'get_the_archive_title', 'editorpro_extend_archive_title' );

endif;

if ( ! function_exists( 'editorpro_customize_tag_cloud' ) ) :
	/**
	 * Customize tag cloud widget
	 */
	function editorpro_customize_tag_cloud( $args ) {
		$args['largest']  = 13;
		$args['smallest'] = 13;
		$args['unit']     = 'px';
		$args['number']   = 20;
		return $args;
	}

	add_filter( 'widget_tag_cloud_args', 'editorpro_customize_tag_cloud' );

endif;

/**
 * Add a dropdown icon to top-level menu items.
 */
function instock_add_dropdown_icons( $output, $item, $depth, $args ) {

	// Only add class to 'top level' items on the 'primary' menu.
	if ( 'mobile' !== $args->theme_location ) {
		return $output;
	}

	if ( in_array( 'menu-item-has-children', $item->classes, true ) ) {

		// Add SVG icon to parent items.
		$icon = '<i class="icon-arrow-down"></i>';

		$output .= sprintf(
			'<button class="submenu-expand" tabindex="-1">%s</button>',
			$icon
		);
	}

	return $output;
}
add_filter( 'walker_nav_menu_start_el', 'instock_add_dropdown_icons', 10, 4 );

/**
 * Scriptless social sharing location.
 */
function instock_change_sss_locations( $locations ) {
	$locations['before'] = array(
		'hook'     => 'editorpro_post_title_after',
		'filter'    => false,
		'priority' => 8,
	);
	$locations['after'] = array(
		'hook'     => 'editorpro_post_after',
		'filter'    => false,
		'priority' => 8,
	);
	return $locations;
}
add_filter( 'scriptlesssocialsharing_locations', 'instock_change_sss_locations' );

/**
 * Scriptless social sharing remove heading.
 */
function instock_remove_sss_heading( $heading ) {
	$heading = false;
	return $heading;
}
add_filter( 'scriptlesssocialsharing_heading', 'instock_remove_sss_heading' );

/**
 * Header ad
 */
function editorpro_header_ad() {

	// Exclude homepage.
	if ( is_home() || is_front_page() ) {
		return;
	}

	// Get the ad code
	$code = get_theme_mod( 'header_ad' );

	if ( $code ) {
		echo '<div class="editorpro-header-banner editorpro-banner">' . wp_kses_post( $code ) . '</div>';
	}
}
add_action( 'editorpro_header', 'editorpro_header_ad', 15 );

/**
 * Footer ad
 */
function editorpro_footer_ad() {

	// Get the ad code
	$code = get_theme_mod( 'footer_ad' );

	if ( $code ) {
		echo '<div class="editorpro-footer-banner editorpro-banner">' . wp_kses_post( $code ) . '</div>';
	}
}
add_action( 'editorpro_footer_before', 'editorpro_footer_ad', 1 );
